<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>ShowActiveLayer</name>
    <message>
        <location filename="../ShowActiveLayerInit.js" line="+2"/>
        <source>Show &amp;Only Active</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wyświetl tylko &amp;aktywne</translation>
    </message>
</context>
</TS>
